@@ -9,6 +9,8 @@ use serde::Deserialize;
 use serde::Serialize;
 use std::collections::HashMap;
 use std::fs;
+use std::fs::File;
+use std::io::Read;
 use std::path::{Path, PathBuf};
 use std::str::FromStr;
 use thiserror::Error;
@@ -151,26 +153,47 @@ impl ItemSpecs {
     }
 }
 
+fn default_display_mode() -> String {
+    String::from("normal")
+}
+
 #[derive(Deserialize, Debug, Clone, PartialEq)]
 #[serde(rename_all(deserialize = "kebab-case"))]
 pub(crate) struct RenderColumnSpec {
+    #[serde(default)]
+    pub(crate) optional: bool,
     #[serde(default)]
     pub(crate) custom: Option<String>,
+    #[serde(default = "default_display_mode")]
+    pub(crate) display_mode: String,
     #[serde(default)]
     pub(crate) link_to_url: Option<String>,
     #[serde(default)]
     pub(crate) plot: Option<PlotSpec>,
     #[serde(default)]
     pub(crate) custom_plot: Option<CustomPlot>,
-    #[serde(default)]
-    summary_plot: Option<String>,
 }
 
 #[derive(Deserialize, Debug, Clone, PartialEq)]
 #[serde(rename_all(deserialize = "kebab-case"))]
 pub(crate) struct RenderPlotSpec {
     #[serde(default, rename = "spec")]
-    pub(crate) schema: String,
+    pub(crate) schema: Option<String>,
+    #[serde(default, rename = "spec-path")]
+    pub(crate) schema_path: Option<String>,
+}
+
+impl RenderPlotSpec {
+    /// Reads schema for RenderPlotSpec from path and saves it under the schema attribute
+    pub(crate) fn read_schema(&mut self) -> Result<()> {
+        if let Some(path) = self.schema_path.as_ref() {
+            let mut file = File::open(path)?;
+            let mut contents = String::new();
+            file.read_to_string(&mut contents)?;
+            self.schema = Some(contents);
+        }
+        Ok(())
+    }
 }
 
 #[derive(Deserialize, Debug, Clone, PartialEq)]
@@ -179,7 +202,7 @@ pub(crate) struct LinkSpec {
     #[serde(default)]
     pub(crate) column: String,
     #[serde(default)]
-    pub(crate) item: Option<String>,
+    pub(crate) view: Option<String>,
     #[serde(default)]
     pub(crate) table_row: Option<String>,
 }
@@ -190,11 +213,26 @@ pub(crate) struct CustomPlot {
     #[serde(default, rename = "data")]
     plot_data: String,
     #[serde(default, rename = "spec")]
-    schema: String,
+    schema: Option<String>,
+    #[serde(default, rename = "spec-path")]
+    schema_path: Option<String>,
     #[serde(default = "default_vega_controls")]
     vega_controls: String,
 }
 
+impl CustomPlot {
+    /// Reads schema for CustomPlot from path and saves it under the schema attribute
+    pub(crate) fn read_schema(&mut self) -> Result<()> {
+        if let Some(path) = self.schema_path.as_ref() {
+            let mut file = File::open(path)?;
+            let mut contents = String::new();
+            file.read_to_string(&mut contents)?;
+            self.schema = Some(contents);
+        }
+        Ok(())
+    }
+}
+
 fn default_vega_controls() -> String {
     "false".to_string()
 }
@@ -210,6 +248,8 @@ pub(crate) struct PlotSpec {
 pub(crate) struct TickPlot {
     #[serde(default, rename = "scale")]
     pub(crate) scale_type: String,
+    #[serde(default)]
+    pub(crate) domain: Option<Vec<f32>>,
 }
 
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq)]
@@ -221,6 +261,8 @@ pub(crate) struct Heatmap {
     color_scheme: String,
     #[serde(default, rename = "range")]
     color_range: Vec<String>,
+    #[serde(default)]
+    pub(crate) domain: Option<Vec<String>>,
 }
 
 #[derive(Error, Debug)]
@@ -247,11 +289,12 @@ mod tests {
     #[test]
     fn test_table_config_deserialization() {
         let expected_render_columns = RenderColumnSpec {
+            optional: false,
             custom: None,
+            display_mode: "normal".to_string(),
             link_to_url: Some(String::from("https://www.rust-lang.org")),
             plot: None,
             custom_plot: None,
-            summary_plot: None,
         };
 
         let expected_dataset_spec = DatasetSpecs {
@@ -301,14 +344,17 @@ mod tests {
     #[test]
     fn test_plot_config_deserialization() {
         let expected_render_plot = RenderPlotSpec {
-            schema: "{'$schema': 'https://vega.github.io/schema/vega-lite/v5.json'}\n".to_string(),
+            schema: Some(
+                "{'$schema': 'https://vega.github.io/schema/vega-lite/v5.json'}\n".to_string(),
+            ),
+            schema_path: None,
         };
 
         let expected_links = HashMap::from([(
             "my-link".to_string(),
             LinkSpec {
                 column: "test".to_string(),
-                item: Some("other-table".to_string()),
+                view: Some("other-table".to_string()),
                 table_row: None,
             },
         )]);
@@ -342,7 +388,7 @@ mod tests {
             links:
                 my-link:
                     column: test
-                    item: other-table
+                    view: other-table
     views:
         plot-a:
             dataset: table-a
